# OpenGL1.5

いにしえのAPI。
知識が無駄になるので、
最初から `OpenGL4` 以降ではじめるのがお勧め。

```{gitinclude} HEAD src/glglue/sample/samplecontroller.py
:language: python
:caption:
```

```{gitinclude} HEAD src/glglue/sample/coord.py
:language: python
:caption:
```

```{gitinclude} HEAD src/glglue/sample/cube.py
:language: python
:caption:
```
